@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: void
 version: 0.7.1
-id: void-0.7.1-5298c6b3a32576797627b9b87532f9cb
-key: void_ATIQ3UuwJfzJFZ7xZqoUa6
+id: void-0.7.1-255c5771d2d826ed3cb8a752061ff594
+key: void_BcWcxbnMYo3FwGZuW3nHt1
 license: BSD3
 copyright: Copyright (C) 2008-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -21,13 +21,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/void-0.7.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/void-0.7.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/void-0.7.1
-hs-libraries: HSvoid-0.7.1-ATIQ3UuwJfzJFZ7xZqoUa6
+hs-libraries: HSvoid-0.7.1-BcWcxbnMYo3FwGZuW3nHt1
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
 haddock-interfaces: /usr/share/doc/haskell-void/html/void.haddock
 haddock-html: /usr/share/doc/haskell-void/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
